==> haskell-lexer-1.0.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lexer
version:              1.0.2
visibility:           public
id:                   haskell-lexer-1.0.2-9BigoExuMgU2wqX65fdMUY
key:                  haskell-lexer-1.0.2-9BigoExuMgU2wqX65fdMUY
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Thomas Hallgren
homepage:             https://github.com/yav/haskell-lexer
synopsis:             A fully compliant Haskell 98 lexer.
description:          A fully compliant Haskell 98 lexer.
category:             Language
abi:                  24e38af5f13f1e2348775a685a46e153
exposed:              True
exposed-modules:      Language.Haskell.Lexer
hidden-modules:
    Language.Haskell.Lexer.Layout Language.Haskell.Lexer.Tokens
    Language.Haskell.Lexer.Lex Language.Haskell.Lexer.Utils
    Language.Haskell.Lexer.Position

import-dirs:          /usr/lib/ghc-8.8.1/site-local/haskell-lexer-1.0.2
library-dirs:         /usr/lib/ghc-8.8.1/site-local/haskell-lexer-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/haskell-lexer-1.0.2
hs-libraries:         HShaskell-lexer-1.0.2-9BigoExuMgU2wqX65fdMUY
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html:         /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lexer-1.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lexer
version:              1.1
visibility:           public
id:                   haskell-lexer-1.1-6vhYTJJkEEY3SkGEX9nN9F
key:                  haskell-lexer-1.1-6vhYTJJkEEY3SkGEX9nN9F
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Thomas Hallgren
homepage:             https://github.com/yav/haskell-lexer
synopsis:             A fully compliant Haskell 98 lexer.
description:          A fully compliant Haskell 98 lexer.
category:             Language
abi:                  1f18be842ee8c5711b3b4d459c687c60
exposed:              True
exposed-modules:      Language.Haskell.Lexer
hidden-modules:
    Language.Haskell.Lexer.Layout Language.Haskell.Lexer.Tokens
    Language.Haskell.Lexer.Lex Language.Haskell.Lexer.Utils
    Language.Haskell.Lexer.Position

import-dirs:          /usr/lib/ghc-8.8.1/site-local/haskell-lexer-1.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/haskell-lexer-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/haskell-lexer-1.1
hs-libraries:         HShaskell-lexer-1.1-6vhYTJJkEEY3SkGEX9nN9F
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html:         /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
